summaryrefslogtreecommitdiffstats
path: root/kjsembed/kjsembedpart.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
commit479f5f799523bffbcc83dff581a2299c047c6fff (patch)
tree186aae707ed02aac6c7cab2fb14e97f72aca5e36 /kjsembed/kjsembedpart.h
parentf1dbff6145c98324ff82e34448b7483727e8ace4 (diff)
downloadtdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.tar.gz
tdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebindings@1157645 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kjsembed/kjsembedpart.h')
-rw-r--r--kjsembed/kjsembedpart.h80
1 files changed, 40 insertions, 40 deletions
diff --git a/kjsembed/kjsembedpart.h b/kjsembed/kjsembedpart.h
index 4645cf60..e9be3efc 100644
--- a/kjsembed/kjsembedpart.h
+++ b/kjsembed/kjsembedpart.h
@@ -22,7 +22,7 @@
#ifndef KJSEMBEDJSCONSOLEPART_H
#define KJSEMBEDJSCONSOLEPART_H
#include "global.h"
-#include <qstringlist.h>
+#include <tqstringlist.h>
#ifndef QT_ONLY
#include <kparts/part.h>
@@ -63,25 +63,25 @@ class JSBuiltIn;
* @author Richard Moore, rich@kde.org
* This is the easiest class for interacting and embedding the interpreter. To use KJSEmbed in yours
* application you can simply create a new KJSEmbedPart. Once you have this object you can expose your
* QObect based classes with a few simple methods. The interface also allows for the manipulation of QVariant data
* structures between Javascript and C++. Complex Javascript arrays are transparently converted to QMaps and QValueLists
* depending on the type of the Array. KJSEmbed also provides transparent access to most QVariant datatypes between
* C++ and Javascript. The easiest way to integrate KJSEmbed into your application is to create a QObject based class
* that will be your interface between C++ and Javascript. This object than can expose C++ methods via Qt slots, and
* QVariant datatypes via Qt properties. This class will also have an interface where C++ objects can call Javascript
* methods.
*/
class KJSEMBED_EXPORT KJSEmbedPart : public KParts::ReadOnlyPart
{
Q_OBJECT
- Q_PROPERTY( QStringList constructorNames READ constructorNames )
- Q_PROPERTY( QCString versionString READ versionString )
+ Q_PROPERTY( TQStringList constructorNames READ constructorNames )
+ Q_PROPERTY( TQCString versionString READ versionString )
Q_PROPERTY( int versionMajor READ versionMajor )
Q_PROPERTY( int versionMinor READ versionMinor )
public:
/** Create a KJSEmbedPart. */
- KJSEmbedPart( QObject *parent=0, const char *name=0 );
+ KJSEmbedPart( TQObject *parent=0, const char *name=0 );
/**
* Creates a KJSEmbedPart for which the parents of the view and part are different.
@@ -92,15 +92,15 @@ public:
* constructor. This results in the widget trying to do GUI related things
* after the QPaint stuff is destroyed.
*/
- KJSEmbedPart( QWidget *wparent, const char *wname=0, QObject *parent=0, const char *name=0 );
+ KJSEmbedPart( TQWidget *wparent, const char *wname=0, TQObject *parent=0, const char *name=0 );
/**
* Create a KJSEmbedPart with the specified interpreter.
*
* See warning above.
*/
- KJSEmbedPart( KJS::Interpreter *js, QWidget *wparent, const char *wname=0,
- QObject *parent=0, const char *name=0 );
+ KJSEmbedPart( KJS::Interpreter *js, TQWidget *wparent, const char *wname=0,
+ TQObject *parent=0, const char *name=0 );
/** Cleans up. */
virtual ~KJSEmbedPart();
@@ -110,7 +110,7 @@ public:
//
/** Returns the version of KJSEmbed. */
- QCString versionString() const;
+ TQCString versionString() const;
/** Returns the minor version number of KJSEmbed. */
int versionMajor() const;
@@ -129,53 +129,53 @@ public:
* else
* ... // function not present.
*/
- bool hasMethod( const QString &methodName );
+ bool hasMethod( const TQString &methodName );
/** Calls a method from Javascript starting from the global context.
* @code
* KJS::List args;
* args.append(KJS::String("String Arg") );
* args.append(KJS::Number(10) );
- * args.append(KJSEmbed::convertToValue(js->globalExec(), QColor("blue" ) ) );
+ * args.append(KJSEmbed::convertToValue(js->globalExec(), TQColor("blue" ) ) );
* KJS::Value val = js->callMethod("javascriptFunction", args );
- * QString myString = val.toString().qstring();
+ * TQString myString = val.toString().qstring();
* @endcode
*/
- KJS::Value callMethod(const QString &methodName, const KJS::List &args) const;
+ KJS::Value callMethod(const TQString &methodName, const KJS::List &args) const;
/** Gets a value from Javascript starting from the global context.
* @code
* KJS::Value val = js->getValue("someValue");
- * QString myString = val.toString().qstring();
+ * TQString myString = val.toString().qstring();
* @endcode
*/
- KJS::Value getValue( const QString &valueName ) const;
+ KJS::Value getValue( const TQString &valueName ) const;
/** Sets a value in a Javascript starting from the global context.
* Note if this value is not present in the javascript context it will
* become defined once this method is called.
* @code
- * KJS::Value val = KJSEmbed::convertToValue(js->globalExec(), QColor("blue"));
+ * KJS::Value val = KJSEmbed::convertToValue(js->globalExec(), TQColor("blue"));
* js->putValue("myVar", val);
* @endcode
*/
- void putValue( const QString &valueName, const KJS::Value &value);
+ void putValue( const TQString &valueName, const KJS::Value &value);
/** Convinence method that wraps around @ref putValue that only handles values
* that are supported by QVariant.
* @code
- * js->putVariant( "myVar", QColor("blue") );
+ * js->putVariant( "myVar", TQColor("blue") );
* @endcode
*/
- void putVariant( const QString &valueName, const QVariant &value);
+ void putVariant( const TQString &valueName, const TQVariant &value);
/** Convinence method that wraps around @ref getValue that only handles values
* that are supported by QVariant.
* @code
- * QColor value = js->getVariant( "myVar").toColor();
+ * TQColor value = js->getVariant( "myVar").toColor();
* @endcode
*/
- QVariant getVariant( const QString &valueName ) const;
+ TQVariant getVariant( const TQString &valueName ) const;
/** Returns the global object of the interpreter. */
KJS::Object globalObject() const { return js->globalObject(); }
@@ -191,7 +191,7 @@ public:
* not specified then the name property of 'obj' is used instead.
* @code
* // In C++
- * QObject *myClass = new QObjectBasedClass(this, "jsObject");
+ * TQObject *myClass = new QObjectBasedClass(this, "jsObject");
* js->addObject( myClass );
* // In Javascript
* jsObject.someProperty = "Test Property";
@@ -199,23 +199,23 @@ public:
* kdDebug() << "New Value: " << myClass->someProperty() << endl; // displays "Test Property"
* @endcode
*/
- KJS::Object addObject( QObject *obj, const char *name=0 );
+ KJS::Object addObject( TQObject *obj, const char *name=0 );
/**
* Publishes 'obj' as property 'name' of object 'parent'. The binding is defined
* using @ref JSObjectProxy, and is subject to the current default SecurityPolicy.
*/
- KJS::Object addObject( QObject *obj, KJS::Object &parent, const char *name=0 );
+ KJS::Object addObject( TQObject *obj, KJS::Object &parent, const char *name=0 );
- /** Returns a JS::Object that provides a binding to the specified QObject. */
- KJS::Object bind( QObject *obj );
+ /** Returns a JS::Object that provides a binding to the specified TQObject. */
+ KJS::Object bind( TQObject *obj );
//
// Query the supported types
//
/** Returns a list of the names of the constructors of this interpreter. */
- QStringList constructorNames() const;
+ TQStringList constructorNames() const;
/** Returns a JS Array of the constructors of this interpreter. */
KJS::Value constructors() const;
@@ -242,7 +242,7 @@ public slots:
KJSEmbed::XMLActionClient *actionClient() const { return xmlclient; }
/** Loads the XML actions defined in the specified file to the default XMLActionClient. */
- bool loadActionSet( const QString &file );
+ bool loadActionSet( const TQString &file );
//
// Script environemnt
@@ -258,26 +258,26 @@ public slots:
JSFactory *factory() const { return jsfactory; }
/** Evaluates the specified string, with the specified value as 'this'. */
- virtual KJS::Value evaluate( const QString &script, const KJS::Value &self=KJS::Null() );
+ virtual KJS::Value evaluate( const TQString &script, const KJS::Value &self=KJS::Null() );
/** Executes the specified string, with the specified value as 'this'. */
- bool execute( const QString &script, const KJS::Value &self=KJS::Null() );
+ bool execute( const TQString &script, const KJS::Value &self=KJS::Null() );
/**
* Executes the specified string, with the specified value as 'this' and sets
* result to the completion object returned by the interpreter.
*/
- virtual bool execute( KJS::Completion &result, const QString &script, const KJS::Value &self );
+ virtual bool execute( KJS::Completion &result, const TQString &script, const KJS::Value &self );
/** Loads and runs the specified file. */
- virtual bool runFile( const QString &filename, const KJS::Value &self=KJS::Null() );
+ virtual bool runFile( const TQString &filename, const KJS::Value &self=KJS::Null() );
/**
* Loads but does not execute the specified script file. If the
* first line of the file starts with the string '#!' then that
* line will be omitted from the returned string.
*/
- QString loadFile( const QString &file );
+ TQString loadFile( const TQString &file );
protected:
/** Creates the interpreter. */
@@ -306,8 +306,8 @@ private:
JSConsoleWidget *jsConsole;
JSFactory *jsfactory;
JSBuiltIn *builtins;
- QWidget *widgetparent;
- QCString widgetname;
+ TQWidget *widgetparent;
+ TQCString widgetname;
KJS::Object partobj;
KJS::Completion res;
@@ -63,25 +63,25 @@ class JSBuiltIn;
* This is the easiest class for interacting and embedding the interpreter. To use KJSEmbed in yours
* application you can simply create a new KJSEmbedPart. Once you have this object you can expose your
- * QObect based classes with a few simple methods. The interface also allows for the manipulation of QVariant data
+ * QObect based classes with a few simple methods. The interface also allows for the manipulation of TQVariant data
* structures between Javascript and C++. Complex Javascript arrays are transparently converted to QMaps and QValueLists
@@ -63,25 +63,25 @@ class JSBuiltIn;
* structures between Javascript and C++. Complex Javascript arrays are transparently converted to QMaps and QValueLists
- * depending on the type of the Array. KJSEmbed also provides transparent access to most QVariant datatypes between
- * C++ and Javascript. The easiest way to integrate KJSEmbed into your application is to create a QObject based class
+ * depending on the type of the Array. KJSEmbed also provides transparent access to most TQVariant datatypes between
+ * C++ and Javascript. The easiest way to integrate KJSEmbed into your application is to create a TQObject based class
* that will be your interface between C++ and Javascript. This object than can expose C++ methods via Qt slots, and
@@ -63,25 +63,25 @@ class JSBuiltIn;
* that will be your interface between C++ and Javascript. This object than can expose C++ methods via Qt slots, and
- * QVariant datatypes via Qt properties. This class will also have an interface where C++ objects can call Javascript
+ * TQVariant datatypes via Qt properties. This class will also have an interface where C++ objects can call Javascript
* methods.
*/
@@ -129,53 +129,53 @@ public:
/** Convinence method that wraps around @ref putValue that only handles values
- * that are supported by QVariant.
+ * that are supported by TQVariant.
* @code
@@ -129,53 +129,53 @@ public:
/** Convinence method that wraps around @ref getValue that only handles values
- * that are supported by QVariant.
+ * that are supported by TQVariant.
* @code